# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/take_it_easy',
                'doc_host': 'https://majoma7.github.io',
                'git_url': 'https://github.com/majoma7/take_it_easy',
                'lib_path': 'take_it_easy'},
  'syms': { 'take_it_easy.board': { 'take_it_easy.board.Board': ('board.html#board', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.__init__': ('board.html#board.__init__', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.__str__': ('board.html#board.__str__', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.get_column_score': ( 'board.html#board.get_column_score',
                                                                                   'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.get_index': ('board.html#board.get_index', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.get_potential_moves': ( 'board.html#board.get_potential_moves',
                                                                                      'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.get_score': ('board.html#board.get_score', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.get_score_potential': ( 'board.html#board.get_score_potential',
                                                                                      'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.is_full': ('board.html#board.is_full', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.put_tile': ('board.html#board.put_tile', 'take_it_easy/board.py'),
                                    'take_it_easy.board.Board.reset': ('board.html#board.reset', 'take_it_easy/board.py')},
            'take_it_easy.play': { 'take_it_easy.play.Game': ('play.html#game', 'take_it_easy/play.py'),
                                   'take_it_easy.play.Game.__init__': ('play.html#game.__init__', 'take_it_easy/play.py'),
                                   'take_it_easy.play.Game.reset': ('play.html#game.reset', 'take_it_easy/play.py'),
                                   'take_it_easy.play.Game.step': ('play.html#game.step', 'take_it_easy/play.py'),
                                   'take_it_easy.play.play_random_game': ('play.html#play_random_game', 'take_it_easy/play.py')},
            'take_it_easy.tiles': { 'take_it_easy.tiles.Tiles': ('tiles.html#tiles', 'take_it_easy/tiles.py'),
                                    'take_it_easy.tiles.Tiles.__init__': ('tiles.html#tiles.__init__', 'take_it_easy/tiles.py'),
                                    'take_it_easy.tiles.Tiles.__str__': ('tiles.html#tiles.__str__', 'take_it_easy/tiles.py'),
                                    'take_it_easy.tiles.Tiles.draw_tile': ('tiles.html#tiles.draw_tile', 'take_it_easy/tiles.py'),
                                    'take_it_easy.tiles.Tiles.input_tile': ('tiles.html#tiles.input_tile', 'take_it_easy/tiles.py'),
                                    'take_it_easy.tiles.Tiles.reset': ('tiles.html#tiles.reset', 'take_it_easy/tiles.py')}}}
